@@ -9,8 +9,14 @@ from rich.console import Console
 
 from exosphere.ui.app import ExosphereUi
 
+ROOT_HELP = """
+Exosphere User Interface
+
+Commands to start the Text-based or Web-based User Interface.
+"""
+
 app = typer.Typer(
-    help="Exosphere UI",
+    help=ROOT_HELP,
     no_args_is_help=True,
 )
 
@@ -39,7 +45,7 @@ def webstart() -> None:
             "The Exosphere Web UI component is not installed. "
             r"Please install 'exosphere-cli\[web]' to use this feature."
         )
-        raise typer.Exit(code=1)
+        raise typer.Exit(code=2)  # Argument error
     else:
         logger.info("Starting Exosphere Web UI Server")
         server = Server(command="exosphere ui start")
