@@ -1,6 +1,7 @@
 import inspect
 import logging
-from datetime import datetime
+from datetime import datetime, timezone
+from typing import TypeAlias
 
 from fabric import Connection
 from paramiko.ssh_exception import PasswordRequiredException
@@ -18,6 +19,10 @@ from exosphere.providers.api import PkgManager
 from exosphere.security import SudoPolicy, check_sudo_policy
 from exosphere.setup import detect
 
+# Define a type alias for timezone-aware UTC datetime
+# This is to help communicate intent better in type hints
+UtcDateTime: TypeAlias = datetime
+
 
 class Host:
     """
@@ -117,8 +122,8 @@ class Host:
         self.updates: list[Update] = []
 
         # Timestamp of the last refresh operation
-        # We store the datetime object straight up for convenience.
-        self.last_refresh: datetime | None = None
+        # This should be a timezone-aware UTC datetime!
+        self.last_refresh: UtcDateTime | None = None
 
     def __getstate__(self) -> dict:
         """
@@ -185,6 +190,53 @@ class Host:
                         f"Missing required parameter '{name}'"
                     )
 
+        # Handle timezone-naive datetimes for backward compatibility
+        if hasattr(self, "last_refresh") and self.last_refresh is not None:
+            if self.last_refresh.tzinfo is None:
+                self.logger.debug(
+                    "Converting timezone-naive last_refresh datetime to UTC for host %s",
+                    self.name,
+                )
+                # We can safely assume the original datetime was in local time
+                # and convert to UTC. This is not IDEAL, but good enough.
+                local_timestamp = self.last_refresh.timestamp()
+                self.last_refresh = datetime.fromtimestamp(
+                    local_timestamp, tz=timezone.utc
+                )
+
+    def to_dict(self) -> dict:
+        """
+        Convert the Host object to a dictionary representation.
+        Useful for serialization or reporting
+
+        Note: Only includes informational fields, does not include
+        configuration or connection details.
+
+        Any datetime fields are represented as ISO 8601 strings in UTC.
+        They explicitly follow what JavaScript's Date.toJSON() produces
+        for maximum compatibility.
+
+        :return: Dictionary representation of the Host object
+        """
+        return {
+            "name": self.name,
+            "description": self.description,
+            "ip": self.ip,
+            "port": self.port,
+            "os": self.os,
+            "flavor": self.flavor,
+            "version": self.version,
+            "supported": self.supported,
+            "online": self.online,
+            "package_manager": self.package_manager,
+            "updates": [update.__dict__.copy() for update in self.updates],
+            "last_refresh": self.last_refresh.isoformat(
+                timespec="milliseconds"
+            ).replace("+00:00", "Z")
+            if self.last_refresh
+            else None,
+        }
+
     @property
     def connection(self) -> Connection:
         """
@@ -272,7 +324,7 @@ class Host:
             return True
 
         stale_threshold = app_config["options"]["stale_threshold"]
-        timedelta = datetime.now() - self.last_refresh
+        timedelta = datetime.now(timezone.utc) - self.last_refresh
 
         return timedelta.total_seconds() > stale_threshold
 
@@ -474,7 +526,7 @@ class Host:
             )
 
         # Update the last refresh timestamp
-        self.last_refresh = datetime.now()
+        self.last_refresh = datetime.now(timezone.utc)
 
     def ping(self, raise_on_error: bool = False) -> bool:
         """
