@@ -1,12 +1,14 @@
 from .debian import Apt
 from .factory import PkgManagerFactory
 from .freebsd import Pkg
+from .openbsd import PkgAdd
 from .redhat import Dnf, Yum
 
 __all__ = [
     "Apt",
     "Dnf",
     "Pkg",
+    "PkgAdd",
     "PkgManagerFactory",
     "Yum",
 ]
